@@ -1,25 +1,30 @@
+from django.conf import settings
+
+from . import defaults
+
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = '2014-2019 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('get_setting',)
 
-from django.conf import settings
-
-from fobi import defaults
 
 def get_setting(setting, override=None):
-    """
+    """Get setting.
+
     Get a setting from `fobi` conf module, falling back to the default.
 
     If override is not None, it will be used instead of the setting.
 
     :param setting: String with setting name
-    :param override: Value to use when no setting is available. Defaults to None.
+    :param override: Value to use when no setting is available. Defaults to
+        None.
     :return: Setting value.
     """
-    if override is not None:
-        return override
-    if hasattr(settings, 'FOBI_{0}'.format(setting)):
-        return getattr(settings, 'FOBI_{0}'.format(setting))
+    attr_name = 'FOBI_{0}'.format(setting)
+    if hasattr(settings, attr_name):
+        return getattr(settings, attr_name)
     else:
-        return getattr(defaults, setting)
+        if hasattr(defaults, setting):
+            return getattr(defaults, setting)
+        else:
+            return override
