@@ -1,18 +1,28 @@
+from django.utils.translation import gettext_lazy as _
+
 __title__ = 'fobi.constants'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = '2014-2019 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = (
-    'ACTION_CHOICE_REPLACE', 'ACTION_CHOICE_APPEND', 'ACTION_CHOICES',
+    'ACTION_CHOICE_REPLACE',
+    'ACTION_CHOICE_APPEND',
+    'ACTION_CHOICES',
     'CALLBACK_BEFORE_FORM_VALIDATION',
     'CALLBACK_FORM_VALID_BEFORE_SUBMIT_PLUGIN_FORM_DATA',
-    'CALLBACK_FORM_VALID', 'CALLBACK_FORM_VALID_AFTER_FORM_HANDLERS',
-    'CALLBACK_FORM_INVALID', 'CALLBACK_STAGES',
-    'SUBMIT_VALUE_AS_VAL', 'SUBMIT_VALUE_AS_REPR', 'SUBMIT_VALUE_AS_MIX',
+    'CALLBACK_FORM_VALID',
+    'CALLBACK_FORM_VALID_AFTER_FORM_HANDLERS',
+    'CALLBACK_FORM_INVALID',
+    'CALLBACK_STAGES',
+    'SUBMIT_VALUE_AS_VAL',
+    'SUBMIT_VALUE_AS_REPR',
+    'SUBMIT_VALUE_AS_MIX',
+    'WIZARD_TYPE_SESSION',
+    'WIZARD_TYPE_COOKIE',
+    'WIZARD_TYPES',
+    'DEFAULT_WIZARD_TYPE',
 )
 
-from django.utils.translation import ugettext_lazy as _
-
 ACTION_CHOICE_REPLACE = '1'
 ACTION_CHOICE_APPEND = '2'
 ACTION_CHOICES = (
@@ -21,7 +31,8 @@ ACTION_CHOICES = (
 )
 
 CALLBACK_BEFORE_FORM_VALIDATION = 'before_form_validation'
-CALLBACK_FORM_VALID_BEFORE_SUBMIT_PLUGIN_FORM_DATA = 'before_submit_plugin_form_data'
+CALLBACK_FORM_VALID_BEFORE_SUBMIT_PLUGIN_FORM_DATA = \
+    'before_submit_plugin_form_data'
 CALLBACK_FORM_VALID = 'form_valid'
 CALLBACK_FORM_VALID_AFTER_FORM_HANDLERS = 'after_form_handlers'
 CALLBACK_FORM_INVALID = 'form_invalid'
@@ -36,3 +47,11 @@ CALLBACK_STAGES = (
 SUBMIT_VALUE_AS_VAL = 'val'
 SUBMIT_VALUE_AS_REPR = 'repr'
 SUBMIT_VALUE_AS_MIX = 'mix'
+
+WIZARD_TYPE_SESSION = 'SessionWizardView'
+WIZARD_TYPE_COOKIE = 'CookieWizardView'
+DEFAULT_WIZARD_TYPE = WIZARD_TYPE_SESSION
+WIZARD_TYPES = (
+    (WIZARD_TYPE_SESSION, "Session wizard"),
+    (WIZARD_TYPE_COOKIE, "Cookie wizard"),
+)
