@@ -1,28 +1,31 @@
-__title__ = 'fobi.context_processors'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('theme', 'dynamic_values', 'form_importers',)
-
 import datetime
 
-from fobi.base import get_theme
-from fobi.helpers import StrippedRequest
-from fobi.form_importers import get_form_impoter_plugin_urls
+from .base import get_theme
+from .form_importers import get_form_importer_plugin_urls
+from .helpers import StrippedRequest
+
+__title__ = 'fobi.context_processors'
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = '2014-2019 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
+__all__ = (
+    'dynamic_values',
+    'form_importers',
+    'theme',
+)
+
 
 def theme(request):
-    """
-    Gets active theme.
+    """Get active theme.
 
     :param django.http.HttpRequest request:
     :return fobi.base.BaseTheme: Instance of ``fobi.base.BaseTheme``.
     """
     return {'fobi_theme': get_theme(request, as_instance=True)}
 
+
 def dynamic_values(request):
-    """
-    Dynamic values exposed to public forms.
-    """
+    """Dynamic values exposed to public forms."""
     return {
         'fobi_dynamic_values': {
             'request': StrippedRequest(request),
@@ -31,10 +34,9 @@ def dynamic_values(request):
         }
     }
 
+
 def form_importers(request):
-    """
-    Form importers.
-    """
+    """Form importers."""
     return {
-        'form_importers': get_form_impoter_plugin_urls(),
+        'form_importers': get_form_importer_plugin_urls(),
     }
