@@ -1,16 +1,18 @@
-__title__ = 'fobi.contrib.apps.wagtail_integration.conf'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('get_setting',)
-
 from django.conf import settings
 
 from . import defaults
 
+__title__ = 'fobi.contrib.apps.wagtail_integration.conf'
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = '2014-2019 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
+__all__ = ('get_setting',)
+
+
 def get_setting(setting, override=None):
-    """
-    Get a setting from ``fobi.contrib.apps.feincms_integration`` conf module,
+    """Get setting.
+
+    Get a setting from ``fobi.contrib.apps.wagtail_integration`` conf module,
     falling back to the default.
 
     If override is not None, it will be used instead of the setting.
@@ -23,6 +25,9 @@ def get_setting(setting, override=None):
     if override is not None:
         return override
     if hasattr(settings, 'FOBI_WAGTAIL_INTEGRATION_{0}'.format(setting)):
-        return getattr(settings, 'FOBI_WAGTAIL_INTEGRATION_{0}'.format(setting))
+        return getattr(
+            settings,
+            'FOBI_WAGTAIL_INTEGRATION_{0}'.format(setting)
+        )
     else:
         return getattr(defaults, setting)
