@@ -1,9 +1,12 @@
 __title__ = 'fobi.contrib.plugins.form_elements.content.content_video.defaults'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = '2014-2019 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = (
-    'SIZES', 'SIZE_400x300', 'SIZE_500x400', 'DEFAULT_SIZE',
+    'SIZES',
+    'SIZE_400x300',
+    'SIZE_500x400',
+    'DEFAULT_SIZE',
 )
 SIZE_400x300 = '400x300'
 SIZE_500x400 = '500x400'
