@@ -1,15 +1,18 @@
-__title__ = 'fobi.contrib.plugins.form_elements.fields.checkbox_select_multiple.conf'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('get_setting',)
-
 from django.conf import settings
 
 from . import defaults
 
+__title__ = 'fobi.contrib.plugins.form_elements.fields.' \
+            'checkbox_select_multiple.conf'
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = '2014-2019 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
+__all__ = ('get_setting',)
+
+
 def get_setting(setting, override=None):
-    """
+    """Get setting.
+
     Get a setting from
     `fobi.contrib.plugins.form_elements.fields.checkbox_select_multiple` conf
     module, falling back to the default.
@@ -23,7 +26,13 @@ def get_setting(setting, override=None):
     """
     if override is not None:
         return override
-    if hasattr(settings, 'FOBI_FORM_ELEMENT_CHECKBOX_SELECT_MULTIPLE_{0}'.format(setting)):
-        return getattr(settings, 'FOBI_FORM_ELEMENT_CHECKBOX_SELECT_MULTIPLE_{0}'.format(setting))
+    if hasattr(
+            settings,
+            'FOBI_FORM_ELEMENT_CHECKBOX_SELECT_MULTIPLE_{0}'.format(setting)
+    ):
+        return getattr(
+            settings,
+            'FOBI_FORM_ELEMENT_CHECKBOX_SELECT_MULTIPLE_{0}'.format(setting)
+        )
     else:
         return getattr(defaults, setting)
