@@ -1,6 +1,7 @@
-__title__ = 'fobi.contrib.plugins.form_elements.fields.hidden_model_object.default'
+__title__ = 'fobi.contrib.plugins.form_elements.fields.' \
+            'hidden_model_object.default'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
+__copyright__ = '2014-2019 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('IGNORED_MODELS',)
 
