@@ -1,8 +1,16 @@
-__title__ = 'fobi.contrib.plugins.form_handlers.db_store.helpers'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('DataExporter',)
+import csv
+import logging
+
+from django.http import HttpResponse
+
+import simplejson as json
+
+from six import StringIO, BytesIO, text_type
+
+from .....exceptions import ImproperlyConfigured
+from .....helpers import safe_text
+
+from .settings import CSV_DELIMITER, CSV_QUOTECHAR
 
 XLWT_INSTALLED = False
 try:
@@ -11,55 +19,49 @@ try:
 except ImportError:
     pass
 
-import csv
+__title__ = 'fobi.contrib.plugins.form_handlers.db_store.helpers'
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = '2014-2019 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
+__all__ = ('DataExporter',)
 
-#import json
-import simplejson as json
 
-from six import StringIO, BytesIO
+LOGGER = logging.getLogger(__name__)
 
-from django.http import HttpResponse
-
-from nine.versions import DJANGO_GTE_1_7
-
-from fobi.exceptions import ImproperlyConfigured
-from fobi.helpers import safe_text
-
-from .settings import CSV_DELIMITER, CSV_QUOTECHAR
 
 class DataExporter(object):
-    """
-    Exporting the data.
-    """
-    def __init__(self, queryset):
+    """Exporting the data."""
+
+    def __init__(self, queryset, only_args):
+        """Constructor."""
         self.queryset = queryset
+        self.only_args = only_args
 
     def _get_initial_response(self, mimetype="application/csv"):
-        """
+        """Get initial response.
+
         For compatibility with older versions (`mimetype` vs `content_type`).
         """
-        response_kwargs = {}
-        if DJANGO_GTE_1_7:
-            response_kwargs['content_type'] = mimetype
-        else:
-            response_kwargs['mimetype'] = mimetype
+        response_kwargs = {'content_type': mimetype}
         return HttpResponse(**response_kwargs)
 
     def _get_data_headers(self):
-        """
+        """Get data headers.
+
         Since we have to deal with non-structured form data, we want to make
         sure that we obtain all the possible headers, so that later on
         we can just fill the slots needed.
         """
+        only_args = ['form_data_headers'] + self.only_args
         # Normal RDMBs
         try:
-            qs = self.queryset.only('form_data_headers')
-            qs = qs.distinct('form_data_headers')
+            qs = self.queryset.only(*only_args)
+            qs = qs.distinct('form_data_headers').order_by('form_data_headers')
             qs = [obj.form_data_headers for obj in qs]
 
         # Engines like SQLite
         except NotImplementedError:
-            qs = self.queryset.only('form_data_headers')
+            qs = self.queryset.only(*only_args)
             qs = [obj.form_data_headers for obj in qs]
             qs = list(set(qs))
 
@@ -74,14 +76,12 @@ class DataExporter(object):
         return data_headers
 
     def _export_to_xls(self):
-        """
-        Export data to XLS format.
-        """
-        #cellstyle = xlwt.easyxf(
+        """Export data to XLS format."""
+        # cellstyle = xlwt.easyxf(
         #    'align: wrap on, vert top, horiz left;', num_format_str='general'
-        #    )
+        # )
 
-        #response = HttpResponse(mimetype="application/csv")
+        # response = HttpResponse(mimetype="application/csv")
         response = self._get_initial_response(mimetype="application/csv")
         response['Content-Disposition'] = \
             'attachment; filename=db_store_export_data.xls'
@@ -100,15 +100,15 @@ class DataExporter(object):
         data_values = data_headers.values()
 
         for cell, value in enumerate(data_values):
-            ws.write(row, cell, unicode(value), xlwt.easyxf('font: bold on'))
-            ws.col(cell).width = 256 * 20 # about 20 chars wide
+            ws.write(row, cell, text_type(value), xlwt.easyxf('font: bold on'))
+            ws.col(cell).width = 256 * 20  # about 20 chars wide
             cell += 1
         row += 1
 
         for obj in self.queryset:
             data = json.loads(obj.saved_data)
             for cell, key in enumerate(data_keys):
-                ws.write(row, cell, unicode(data.get(key, '')))
+                ws.write(row, cell, text_type(data.get(key, '')))
                 cell += 1
 
             row += 1
@@ -117,18 +117,17 @@ class DataExporter(object):
         return response
 
     def export_to_xls(self):
+        """Export data to XLS."""
         if XLWT_INSTALLED:
             return self._export_to_xls()
         else:
             raise ImproperlyConfigured(
                 "For XLS export xlwt shall be installed."
-                )
+            )
 
     def export_to_csv(self):
-        """
-        Export data to CSV.
-        """
-        #response = HttpResponse(mimetype="text/csv")
+        """Export data to CSV."""
+        # response = HttpResponse(mimetype="text/csv")
         response = self._get_initial_response(mimetype="text/csv")
         response['Content-Disposition'] = \
             'attachment; filename=db_store_export_data.csv'
@@ -141,7 +140,7 @@ class DataExporter(object):
         try:
             csv_obj = csv.writer(
                 queue, delimiter=CSV_DELIMITER, quotechar=CSV_QUOTECHAR
-                )
+            )
             writerow = csv_obj.writerow
         except TypeError:
             queue = BytesIO()
@@ -149,9 +148,12 @@ class DataExporter(object):
             quotechar = bytes(CSV_QUOTECHAR, encoding="utf-8")
             csv_obj = csv.writer(
                 queue, delimiter=delimiter, quotechar=quotechar
-                )
-            writerow = lambda row: csv.writerow(
-                [safe_text(cell) for cell in row]
+            )
+
+            def writerow(row):
+                """Write row."""
+                return csv.writerow(
+                    [safe_text(__cell) for __cell in row]
                 )
 
         data_values = [safe_text(value) for value in data_values]
@@ -171,9 +173,7 @@ class DataExporter(object):
         return response
 
     def graceful_export(self):
-        """
-        Export data into XLS/CSV depending on what is available.
-        """
+        """Export data into XLS/CSV depending on what is available."""
         if XLWT_INSTALLED:
             return self._export_to_xls()
         else:
