@@ -1,17 +1,17 @@
-__title__ = 'fobi.contrib.plugins.form_handlers.db_store.widgets'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('BaseDbStorePluginWidget',)
-
-from fobi.base import FormHandlerPluginWidget
+from .....base import FormHandlerPluginWidget
 
 from . import UID
 
+__title__ = 'fobi.contrib.plugins.form_handlers.db_store.widgets'
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = '2014-2019 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
+__all__ = ('BaseDbStorePluginWidget',)
+
+
 class BaseDbStorePluginWidget(FormHandlerPluginWidget):
-    """
-    Base dummy form element plugin widget.
-    """
+    """Base dummy form element plugin widget."""
+
     plugin_uid = UID
     view_entries_icon_class = 'glyphicon glyphicon-list'
     export_entries_icon_class = 'glyphicon glyphicon-export'
