@@ -1,9 +1,10 @@
 __title__ = 'fobi.contrib.plugins.form_handlers.http_repost'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = '2014-2019 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('default_app_config', 'UID',)
 
-default_app_config = 'fobi.contrib.plugins.form_handlers.http_repost.apps.Config'
+default_app_config = 'fobi.contrib.plugins.form_handlers.' \
+                     'http_repost.apps.Config'
 
 UID = 'http_repost'
