@@ -1,15 +1,17 @@
-__title__ = 'fobi.contrib.plugins.form_importers.mailchimp_importer.forms'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('MailchimpAPIKeyForm', 'MailchimpListIDForm',)
-
 import mailchimp
 
 from django import forms
 
+__title__ = 'fobi.contrib.plugins.form_importers.mailchimp_importer.forms'
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = '2014-2019 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
+__all__ = ('MailchimpAPIKeyForm', 'MailchimpListIDForm',)
+
+
 class MailchimpAPIKeyForm(forms.Form):
-    """
+    """MailchimpAPIKeyForm.
+
     First form the the wizard. Here users are supposed to provide the
     API key of their Mailchimp account.
     """
@@ -17,15 +19,15 @@ class MailchimpAPIKeyForm(forms.Form):
 
 
 class MailchimpListIDForm(forms.Form):
-    """
+    """MailchimpListIDForm.
+
     Second form of the wizard. Here users are supposed to choose the form
     they want to import.
     """
     list_id = forms.ChoiceField(required=True, choices=[])
 
     def __init__(self, *args, **kwargs):
-        """
-        """
+        """Constructor."""
         self._api_key = None
 
         if 'api_key' in kwargs:
@@ -38,5 +40,5 @@ class MailchimpListIDForm(forms.Form):
             lists = client.lists.list()
             choices = [(l['id'], l['name']) for l in lists['data']]
             self.fields['list_id'].choices = choices
-        #else:
-        #    self.fields['list_id'] = forms.CharField(required=True)
+        # else:
+        #     self.fields['list_id'] = forms.CharField(required=True)
