@@ -54,29 +54,29 @@ $(document).ready(function() {
  * Draggable form elements.
  */
 $(function() {
-	// Matching regex with jQuery
-	$.expr[':'].regex = function(elem, index, match) {
-	    var matchParams = match[3].split(','),
-	        validLabels = /^(data|css):/,
-	        attr = {
-	            method: matchParams[0].match(validLabels) ?
-	                        matchParams[0].split(':')[0] : 'attr',
-	            property: matchParams.shift().replace(validLabels,'')
-	        },
-	        regexFlags = 'ig',
-	        regex = new RegExp(matchParams.join('').replace(/^\s+|\s+$/g,''), regexFlags);
-	    return regex.test($(elem)[attr.method](attr.property));
-	}
+    // Matching regex with jQuery
+    $.expr[':'].regex = function(elem, index, match) {
+        var matchParams = match[3].split(','),
+            validLabels = /^(data|css):/,
+            attr = {
+                method: matchParams[0].match(validLabels) ?
+                            matchParams[0].split(':')[0] : 'attr',
+                property: matchParams.shift().replace(validLabels,'')
+            },
+            regexFlags = 'ig',
+            regex = new RegExp(matchParams.join('').replace(/^\s+|\s+$/g,''), regexFlags);
+        return regex.test($(elem)[attr.method](attr.property));
+    }
 
     formElementPositionElements = $('.form-element-position');
     if (formElementPositionElements.length) {
-        $('.form-horizontal .form-group').css({ 'cursor': 'move' });
+        $('#fobi-form .form-group').css({ 'cursor': 'move' });
 
-        $('.form-horizontal').sortable({
+        $('#fobi-form').sortable({
             axis: 'y',
-            items: ".form-group",
+            items: '.form-group',
             update: function(){
-                $.each($('.form-horizontal .form-group'), function(i){
+                $.each($('#fobi-form .form-group'), function(i){
                     $(this).find('input:regex(name, .*-position)').val(i + 1);
                 });
 
