@@ -1,9 +1,10 @@
 __title__ = 'fobi.contrib.themes.djangocms_admin_style_theme'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2015 Artur Barseghyan'
+__copyright__ = '2015-2019 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('default_app_config', 'UID',)
 
-default_app_config = 'fobi.contrib.themes.djangocms_admin_style_theme.apps.Config'
+default_app_config = 'fobi.contrib.themes.' \
+                     'djangocms_admin_style_theme.apps.Config'
 
 UID = 'djangocms_admin_style_theme'
