@@ -1,7 +1,8 @@
 __title__ = 'fobi.contrib.themes.simple.widgets.form_handlers.db_store'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = '2014-2019 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('default_app_config',)
 
-default_app_config = 'fobi.contrib.themes.simple.widgets.form_handlers.db_store.apps.Config'
+default_app_config = 'fobi.contrib.themes.simple.widgets.form_handlers.' \
+                     'db_store.apps.Config'
