@@ -1,16 +1,17 @@
-__title__ = 'fobi.data_structures'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('SortableDict', )
-
 import copy
 
 import six
 
+__title__ = 'fobi.data_structures'
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = '2014-2019 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
+__all__ = ('SortableDict', )
+
 
 class SortableDict(dict):
-    """
+    """SortableDict.
+
     A dictionary that keeps its keys in the order in which they're
     inserted. Very similar to (and partly based on) ``SortedDict`` of
     the ``Django``, but has several additional methods implemented,
@@ -18,11 +19,13 @@ class SortableDict(dict):
     """
 
     def __new__(cls, *args, **kwargs):
+        """New."""
         instance = super(SortableDict, cls).__new__(cls, *args, **kwargs)
         instance.key_order = []
         return instance
 
     def __init__(self, data=None):
+        """Constructor."""
         if data is None or isinstance(data, dict):
             data = data or []
             super(SortableDict, self).__init__(data)
@@ -62,21 +65,24 @@ class SortableDict(dict):
     def __reversed__(self):
         return reversed(self.key_order)
 
-    def pop(self, k, *args):
-        result = super(SortableDict, self).pop(k, *args)
+    def pop(self, key, *args):
+        """Pop."""
+        result = super(SortableDict, self).pop(key, *args)
         try:
-            self.key_order.remove(k)
+            self.key_order.remove(key)
         except ValueError:
             # Key wasn't in the dictionary in the first place. No problem.
             pass
         return result
 
     def popitem(self):
+        """Pop item."""
         result = super(SortableDict, self).popitem()
         self.key_order.remove(result[0])
         return result
 
     def _iteritems(self):
+        """Iter items (internal method)."""
         for key in self.key_order:
             yield key, self[key]
 
@@ -85,6 +91,7 @@ class SortableDict(dict):
             yield key
 
     def _itervalues(self):
+        """Iter values (internal method)."""
         for key in self.key_order:
             yield self[key]
 
@@ -98,19 +105,21 @@ class SortableDict(dict):
         itervalues = _itervalues
 
         def items(self):
-            return [(k, self[k]) for k in self.key_order]
+            return [(key, self[key]) for key in self.key_order]
 
         def keys(self):
             return self.key_order[:]
 
         def values(self):
-            return [self[k] for k in self.key_order]
+            return [self[key] for key in self.key_order]
 
     def update(self, dict_):
-        for k, v in six.iteritems(dict_):
-            self[k] = v
+        """Update."""
+        for key, val in six.iteritems(dict_):
+            self[key] = val
 
     def setdefault(self, key, default):
+        """Set default."""
         if key not in self:
             self.key_order.append(key)
         return super(SortableDict, self).setdefault(key, default)
@@ -125,9 +134,9 @@ class SortableDict(dict):
     def insert(self, index, key, value):
         """Inserts the key, value pair before the item with the given index."""
         if key in self.key_order:
-            n = self.key_order.index(key)
-            del self.key_order[n]
-            if n < index:
+            num = self.key_order.index(key)
+            del self.key_order[num]
+            if num < index:
                 index -= 1
         self.key_order.insert(index, key)
         super(SortableDict, self).__setitem__(key, value)
@@ -138,14 +147,16 @@ class SortableDict(dict):
         return self.__class__(self)
 
     def __repr__(self):
-        """
+        """Repr.
+
         Replaces the normal dict.__repr__ with a version that returns the keys
         in their sorted order.
         """
-        return '{%s}' % ', '.join(['%r: %r' % (k, v)
-                                   for k, v in six.iteritems(self)])
+        return '{%s}' % ', '.join(['%r: %r' % (key, val)
+                                   for key, val in six.iteritems(self)])
 
     def clear(self):
+        """Clear."""
         super(SortableDict, self).clear()
         self.key_order = []
 
@@ -156,8 +167,7 @@ class SortableDict(dict):
     def insert_before_key(self, target_key, key, value,
                           fail_silently=True,
                           offset=0):
-        """
-        Inserts the {``key``: ``value``} before the ``target_key``.
+        """Insert the {``key``: ``value``} before the ``target_key``.
 
         :param immutable target_key:
         :param immutable key:
@@ -172,13 +182,13 @@ class SortableDict(dict):
             return True
         elif not fail_silently:
             raise ValueError(
-                "Target key ``{0}`` does not exist.".format(target_key))
+                "Target key ``{0}`` does not exist.".format(target_key)
+            )
         else:
             return False
 
     def insert_after_key(self, target_key, key, value, fail_silently=True):
-        """
-        Inserts the {``key``: ``value``} after the ``target_key``.
+        """Insert the {``key``: ``value``} after the ``target_key``.
 
         :param immutable target_key:
         :param immutable key:
@@ -196,8 +206,7 @@ class SortableDict(dict):
     def move_before_key(self, source_key, target_key,
                         fail_silently=True,
                         offset=0):
-        """
-        Moves the {``key``: ``value``} before the given ``source_key``.
+        """Move the {``key``: ``value``} before the given ``source_key``.
 
         :param immutable source_key:
         :param immutable target_key:
@@ -217,8 +226,7 @@ class SortableDict(dict):
             return False
 
     def move_after_key(self, source_key, target_key, fail_silently=True):
-        """
-        Moves the {``key``: ``value``} after the given ``source_key``.
+        """Move the {``key``: ``value``} after the given ``source_key``.
 
         :param immutable source_key:
         :param immutable target_key:
