@@ -1,54 +1,60 @@
 from __future__ import absolute_import
 
-__title__ = 'fobi.models'
-__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = (
-    # Plugins
-    'AbstractPluginModel', 'FormElement', 'FormHandler',
-
-    # Entries
-    'AbstractPluginEntry', 'FormWizardEntry', 'FormEntry', 'FormElementEntry',
-    'FormFieldsetEntry', 'FormHandlerEntry',
-)
-
 import logging
-logger = logging.getLogger(__name__)
-
-from django.core.urlresolvers import reverse
-from django.db import models
-from django.utils.translation import ugettext_lazy as _
-from django.contrib.auth.models import Group
-from django.conf import settings
 
 from autoslug import AutoSlugField
 
-from fobi.base import (
-    get_registered_form_element_plugins, get_registered_form_handler_plugins,
-    form_element_plugin_registry, form_handler_plugin_registry
+from django.conf import settings
+from django.contrib.auth.models import Group
+from django.db import models
+from django.utils import timezone
+from django.utils.translation import gettext_lazy as _
+from django.urls import reverse
+
+from six import python_2_unicode_compatible
+
+from .base import (
+    form_element_plugin_registry,
+    form_handler_plugin_registry,
+    form_wizard_handler_plugin_registry,
+    get_registered_form_element_plugins,
+    get_registered_form_handler_plugins,
+    get_registered_form_wizard_handler_plugins,
 )
+from .constants import WIZARD_TYPES, DEFAULT_WIZARD_TYPE
+
+__title__ = 'fobi.models'
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = '2014-2019 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
+__all__ = (
+    # Plugins
+    'AbstractPluginModel',
+    'FormElement',
+    'FormHandler',
+    'FormWizardHandler',
+
+    # Entries
+    'AbstractFormWizardPluginEntry',
+    'AbstractPluginEntry',
+    'BaseAbstractPluginEntry',
+    'FormElementEntry',
+    'FormEntry',
+    'FormFieldsetEntry',
+    'FormHandlerEntry',
+    'FormWizardEntry',
+    'FormWizardFormEntry',
+    'FormWizardHandlerEntry',
+)
+
+
+logger = logging.getLogger(__name__)
 
 # ****************************************************************************
 # **************** Safe User import for Django > 1.5, < 1.8 ******************
 # ****************************************************************************
 AUTH_USER_MODEL = settings.AUTH_USER_MODEL
 
-# Note, that this may cause circular imports - thus the ``get_user_model``
-# should be moved elsewhere (be used on the function/method level). For
-# now leave commented and solve in future. Possible use the DjangoCMS solution
-# https://github.com/divio/django-cms/blob/develop/cms/models/permissionmodels.py#L18
-
-# Sanity checks.
-#user = User()
-#
-#if not hasattr(user, 'username'):
-#    from fobi.exceptions import ImproperlyConfigured
-#    raise ImproperlyConfigured("Your custom user model ({0}.{1}) doesn't "
-#                               "have ``username`` property, while "
-#                               "``django-fobi`` relies on its' presence"
-#                               ".".format(user._meta.app_label, user._meta.object_name))
-
 # ****************************************************************************
 # ****************************************************************************
 # ****************************************************************************
@@ -59,9 +65,10 @@ AUTH_USER_MODEL = settings.AUTH_USER_MODEL
 # ****************************************************************************
 # ****************************************************************************
 
+
+@python_2_unicode_compatible
 class AbstractPluginModel(models.Model):
-    """
-    Abstract plugin model.
+    """Abstract plugin model.
 
     Used when ``fobi.settings.RESTRICT_PLUGIN_ACCESS`` is set to True.
 
@@ -73,16 +80,18 @@ class AbstractPluginModel(models.Model):
         - `groups` (django.contrib.auth.models.Group): White list of the
           user groups allowed to use the plugin.
     """
-    #plugin_uid = models.CharField(_("Plugin UID"), max_length=255,
+
+    # plugin_uid = models.CharField(_("Plugin UID"), max_length=255,
     #                              unique=True, editable=False)
     users = models.ManyToManyField(AUTH_USER_MODEL, verbose_name=_("User"),
                                    blank=True)
     groups = models.ManyToManyField(Group, verbose_name=_("Group"), blank=True)
 
-    class Meta:
+    class Meta(object):
+        """Meta class."""
         abstract = True
 
-    #def __init__(self, *args, **kwargs):
+    # def __init__(self, *args, **kwargs):
     #    """
     #    Add choices.
     #    """
@@ -91,20 +100,20 @@ class AbstractPluginModel(models.Model):
     #    plugin_uid._choices = self.get_registered_plugins()
 
     def get_registered_plugins(self):
-        """
-        """
-        raise NotImplemented(
+        """Get registered plugins."""
+        raise NotImplementedError(
             "You should implement ``get_registered_plugins`` method!"
         )
 
-    def __unicode__(self):
+    def __str__(self):
         return "{0} ({1})".format(
             dict(self.get_registered_plugins()).get(self.plugin_uid, ''),
             self.plugin_uid
-            )
+        )
 
     def plugin_uid_code(self):
-        """
+        """Plugin uid code.
+
         Mainly used in admin.
         """
         return self.plugin_uid
@@ -112,15 +121,17 @@ class AbstractPluginModel(models.Model):
     plugin_uid_code.short_description = _('UID')
 
     def plugin_uid_admin(self):
-        """
+        """Plugin uid admin.
+
         Mainly used in admin.
         """
-        return self.__unicode__()
+        return self.__str__()
     plugin_uid_admin.allow_tags = True
     plugin_uid_admin.short_description = _('Plugin')
 
     def groups_list(self):
-        """
+        """Groups list.
+
         Flat list (comma separated string) of groups allowed to use the
         plugin. Used in Django admin.
 
@@ -131,7 +142,8 @@ class AbstractPluginModel(models.Model):
     groups_list.short_description = _('Groups')
 
     def users_list(self):
-        """
+        """Users list.
+
         Flat list (comma separated string) of users allowed to use the
         plugin. Used in Django admin.
 
@@ -143,7 +155,8 @@ class AbstractPluginModel(models.Model):
 
 
 class FormElement(AbstractPluginModel):
-    """
+    """Form element.
+
     Form field plugin. Used when ``fobi.settings.RESTRICT_PLUGIN_ACCESS``
     is set to True.
 
@@ -157,19 +170,18 @@ class FormElement(AbstractPluginModel):
     """
     plugin_uid = models.CharField(
         _("Plugin UID"), max_length=255, unique=True, editable=False,
-        choices=get_registered_form_element_plugins()
+        # choices=get_registered_form_element_plugins()
     )
-    #objects = FormFieldPluginModelManager()
+    # objects = FormFieldPluginModelManager()
 
-    class Meta:
+    class Meta(object):
+        """Meta class."""
         abstract = False
         verbose_name = _("Form element plugin")
         verbose_name_plural = _("Form element plugins")
 
     def get_registered_plugins(self):
-        """
-        Add choices.
-        """
+        """Add choices."""
         return get_registered_form_element_plugins()
 
 
@@ -188,196 +200,427 @@ class FormHandler(AbstractPluginModel):
     """
     plugin_uid = models.CharField(
         _("Plugin UID"), max_length=255, unique=True, editable=False,
-        choices=get_registered_form_handler_plugins()
+        # choices=get_registered_form_handler_plugins()
     )
-    #objects = FormHandlerPluginModelManager()
+    # objects = FormHandlerPluginModelManager()
 
-    class Meta:
+    class Meta(object):
+        """Class meta."""
         abstract = False
         verbose_name = _("Form handler plugin")
         verbose_name_plural = _("Form handler plugins")
 
     def get_registered_plugins(self):
-        """
-        Add choices.
-        """
+        """Add choices."""
         return get_registered_form_handler_plugins()
 
+
+class FormWizardHandler(AbstractPluginModel):
+    """
+    Form wizard handler plugin. Used when
+    ``fobi.settings.RESTRICT_PLUGIN_ACCESS`` is set to True.
+
+    :Properties:
+
+        - `plugin_uid` (str): Plugin UID.
+        - `users` (django.contrib.auth.models.User): White list of the users
+          allowed to use the form handler plugin.
+        - `groups` (django.contrib.auth.models.Group): White list of the
+          user groups allowed to use the form handler plugin.
+    """
+    plugin_uid = models.CharField(
+        _("Plugin UID"), max_length=255, unique=True, editable=False,
+        # choices=get_registered_form_handler_plugins()
+    )
+
+    # objects = FormHandlerPluginModelManager()
+
+    class Meta(object):
+        """Class meta."""
+        abstract = False
+        verbose_name = _("Form wizard handler plugin")
+        verbose_name_plural = _("Form wizard handler plugins")
+
+    def get_registered_plugins(self):
+        """Add choices."""
+        return get_registered_form_wizard_handler_plugins()
+
 # *****************************************************************************
 # *****************************************************************************
 # ******************************** Entry models *******************************
 # *****************************************************************************
 # *****************************************************************************
 
+
+@python_2_unicode_compatible
 class FormWizardEntry(models.Model):
-    """
-    """
-    user = models.ForeignKey(AUTH_USER_MODEL, verbose_name=_("User"))
+    """Form wizard entry."""
+
+    user = models.ForeignKey(
+        AUTH_USER_MODEL,
+        verbose_name=_("User"),
+        on_delete=models.CASCADE
+    )
     name = models.CharField(_("Name"), max_length=255)
-    slug = AutoSlugField(populate_from='name', verbose_name=_("Slug"),
-                         unique=True)
+    title = models.CharField(
+        _("Title"),
+        max_length=255,
+        null=True,
+        blank=True,
+        help_text=_("Shown in templates if available.")
+    )
+    slug = AutoSlugField(
+        populate_from='name',
+        verbose_name=_("Slug"),
+        unique=True
+    )
     is_public = models.BooleanField(
-        _("Is public?"), default=False,
+        _("Is public?"),
+        default=False,
         help_text=_("Makes your form wizard visible to the public.")
     )
     is_cloneable = models.BooleanField(
-        _("Is cloneable?"), default=False,
+        _("Is cloneable?"),
+        default=False,
         help_text=_("Makes your form wizard cloneable by other users.")
     )
-
-    class Meta:
-        verbose_name = _("Form wizard entry")
-        verbose_name_plural = _("Form wizard entries")
-        unique_together = (('user', 'slug'), ('user', 'name'),)
-
-    def __unicode__(self):
-        return self.name
-
-    def get_absolute_url(self):
-        """
-        Absolute URL, which goes to the dashboard workspace page.
-
-        :return string:
-        """
-        return reverse('fobi.form_wizard', kwargs={'slug': self.slug})
-
-
-class FormEntry(models.Model):
-    """
-    Form entry.
-
-    :Properties:
-
-        - `user` (django.contrib.auth.models.User: User owning the plugin.
-        - `wizard` (str): Form wizard to which the form entry belongs to.
-        - `name` (str): Form name.
-        - `slug` (str): Form slug.
-        - `description` (str): Form description.
-        - `is_public` (bool): If set to True, is visible to public.
-        - `is_clonable` (bool): If set to True, is clonable.
-        - `position` (int): Ordering position in the wizard.
-    """
-    form_wizard_entry = models.ForeignKey(
-        FormWizardEntry, verbose_name=_("Form wizard"), null=True, blank=True
-    )
-    user = models.ForeignKey(AUTH_USER_MODEL, verbose_name=_("User"))
-    name = models.CharField(_("Name"), max_length=255)
-    slug = AutoSlugField(
-        populate_from='name', verbose_name=_("Slug"), unique=True
-    )
-    is_public = models.BooleanField(
-        _("Public?"), default=False,
-        help_text=_("Makes your form visible to the public.")
-    )
-    is_cloneable = models.BooleanField(
-        _("Cloneable?"), default=False,
-        help_text=_("Makes your form cloneable by other users.")
-    )
-    position = models.PositiveIntegerField(
-        _("Position"), null=True, blank=True
-    )
     success_page_title = models.CharField(
-        _("Success page title"), max_length=255, null=True, blank=True,
+        _("Success page title"),
+        max_length=255,
+        null=True,
+        blank=True,
         help_text=_("Custom message title to display after valid form is "
                     "submitted")
     )
     success_page_message = models.TextField(
-        _("Success page body"), null=True, blank=True,
+        _("Success page body"),
+        null=True,
+        blank=True,
+        help_text=_("Custom message text to display after valid form is "
+                    "submitted")
+    )
+    show_all_navigation_buttons = models.BooleanField(
+        _("Show all navigation buttons?"),
+        default=False,
+        help_text=_("Show all navigation buttons.")
+    )
+    # action = models.CharField(
+    #     _("Action"), max_length=255, null=True, blank=True,
+    #     help_text=_("Custom form action; don't fill this field, unless "
+    #                 "really necessary.")
+    # )
+    wizard_type = models.CharField(
+        _("Type"),
+        max_length=255,
+        null=False,
+        blank=False,
+        choices=WIZARD_TYPES,
+        default=DEFAULT_WIZARD_TYPE,
+        help_text=_("Type of the form wizard.")
+    )
+    created = models.DateTimeField(
+        _("Created"),
+        null=True,
+        blank=True,
+        auto_now_add=True
+    )
+    updated = models.DateTimeField(
+        _("Updated"),
+        null=True,
+        blank=True,
+        auto_now=True
+    )
+
+    class Meta(object):
+        """Meta class."""
+
+        verbose_name = _("Form wizard entry")
+        verbose_name_plural = _("Form wizard entries")
+        unique_together = (('user', 'slug'), ('user', 'name'),)
+
+    def __str__(self):
+        return self.name
+
+    def get_absolute_url(self):
+        """Get absolute URL.
+
+        Absolute URL, which goes to the form-wizard view view.
+
+        :return string:
+        """
+        return reverse(
+            'fobi.view_form_wizard_entry',
+            kwargs={'form_wizard_entry_slug': self.slug}
+        )
+
+
+@python_2_unicode_compatible
+class FormEntry(models.Model):
+    """Form entry."""
+
+    user = models.ForeignKey(
+        AUTH_USER_MODEL,
+        verbose_name=_("User"),
+        on_delete=models.CASCADE
+    )
+    name = models.CharField(_("Name"), max_length=255)
+    title = models.CharField(
+        _("Title"),
+        max_length=255,
+        null=True,
+        blank=True,
+        help_text=_("Shown in templates if available.")
+    )
+    slug = AutoSlugField(
+        populate_from='name', verbose_name=_("Slug"), unique=True
+    )
+    is_public = models.BooleanField(
+        _("Public?"),
+        default=False,
+        help_text=_("Makes your form visible to the public.")
+    )
+    active_date_from = models.DateTimeField(
+        _("Active from"),
+        null=True,
+        blank=True,
+        help_text=_("Date and time when the form becomes active "
+                    "in the format: 'YYYY-MM-DD HH:MM'. "
+                    "Leave it blank to activate immediately.")
+    )
+    active_date_to = models.DateTimeField(
+        _("Active until"),
+        null=True,
+        blank=True,
+        help_text=_("Date and time when the form becomes inactive "
+                    "in the format: 'YYYY-MM-DD HH:MM'. "
+                    "Leave it blank to keep active forever.")
+    )
+    inactive_page_title = models.CharField(
+        _("Inactive form page title"),
+        max_length=255,
+        null=True,
+        blank=True,
+        help_text=_("Custom message title to display if form is inactive.")
+    )
+    inactive_page_message = models.TextField(
+        _("Inactive form page body"),
+        null=True,
+        blank=True,
+        help_text=_("Custom message text to display if form is inactive.")
+    )
+    is_cloneable = models.BooleanField(
+        _("Cloneable?"),
+        default=False,
+        help_text=_("Makes your form cloneable by other users.")
+    )
+    # position = models.PositiveIntegerField(
+    #     _("Position"), null=True, blank=True
+    # )
+    success_page_title = models.CharField(
+        _("Success page title"),
+        max_length=255,
+        null=True,
+        blank=True,
+        help_text=_("Custom message title to display after valid form is "
+                    "submitted")
+    )
+    success_page_message = models.TextField(
+        _("Success page body"),
+        null=True,
+        blank=True,
         help_text=_("Custom message text to display after valid form is "
                     "submitted")
     )
     action = models.CharField(
-        _("Action"), max_length=255, null=True, blank=True,
+        _("Action"),
+        max_length=255,
+        null=True,
+        blank=True,
         help_text=_("Custom form action; don't fill this field, unless really "
                     "necessary.")
     )
-    created = models.DateTimeField(_("Created"), null=True, blank=True,
-                                   auto_now_add=True)
-    updated = models.DateTimeField(_("Updated"), null=True, blank=True,
-                                   auto_now=True)
+    created = models.DateTimeField(
+        _("Created"),
+        null=True,
+        blank=True,
+        auto_now_add=True
+    )
+    updated = models.DateTimeField(
+        _("Updated"),
+        null=True,
+        blank=True,
+        auto_now=True
+    )
+
+    class Meta(object):
+        """Meta class."""
 
-    class Meta:
         verbose_name = _("Form entry")
         verbose_name_plural = _("Form entries")
         unique_together = (('user', 'slug'), ('user', 'name'),)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
+    @property
+    def is_active(self):
+        active_from_ok = True
+        active_to_ok = True
+        now = timezone.now()
+
+        if self.active_date_from and now < self.active_date_from:
+            active_from_ok = False
+        if self.active_date_to and now > self.active_date_to:
+            active_to_ok = False
+
+        if active_from_ok and active_to_ok:
+            return True
+        else:
+            return False
+
     def get_absolute_url(self):
-        """
-        Absolute URL, which goes to the dashboard workspace page.
+        """Get absolute URL.
+
+        Absolute URL, which goes to the form-entry view view page.
 
         :return string:
         """
-        return reverse('fobi.form_entry', kwargs={'slug': self.slug})
+        return reverse(
+            'fobi.view_form_entry',
+            kwargs={'form_entry_slug': self.slug}
+        )
 
 
+@python_2_unicode_compatible
+class FormWizardFormEntry(models.Model):
+    """Form wizard form entry.
+
+    A coupling point between `FormWizardEntry` and `FormEntry`."""
+
+    form_wizard_entry = models.ForeignKey(
+        FormWizardEntry,
+        verbose_name=_("Form wizard entry"),
+        null=False,
+        blank=False,
+        on_delete=models.CASCADE
+    )
+    form_entry = models.ForeignKey(
+        FormEntry,
+        verbose_name=_("Form entry"),
+        null=False,
+        blank=False,
+        on_delete=models.CASCADE
+    )
+    position = models.PositiveIntegerField(
+        _("Position"),
+        null=True,
+        blank=True
+    )
+
+    class Meta(object):
+        """Meta class."""
+
+        abstract = False
+        verbose_name = _("Form wizard form entry")
+        verbose_name_plural = _("Form wizard form entries")
+        ordering = ['position']
+        unique_together = (('form_wizard_entry', 'form_entry'),)
+
+    def __str__(self):
+        return "{0} - {1}".format(self.form_wizard_entry, self.form_entry)
+
+
+@python_2_unicode_compatible
 class FormFieldsetEntry(models.Model):
-    """
-    Form fieldset entry.
-    """
-    form_entry = models.ForeignKey(FormEntry, verbose_name=_("Form"),
-                                   null=True, blank=True)
+    """Form fieldset entry."""
+
+    form_entry = models.ForeignKey(
+        FormEntry,
+        verbose_name=_("Form"),
+        null=True,
+        blank=True,
+        on_delete=models.CASCADE
+    )
     name = models.CharField(_("Name"), max_length=255)
     is_repeatable = models.BooleanField(
-        _("Is repeatable?"), default=False,
+        _("Is repeatable?"),
+        default=False,
         help_text=_("Makes your form fieldset repeatable.")
     )
 
-    class Meta:
+    class Meta(object):
+        """Meta class."""
+
         verbose_name = _("Form fieldset entry")
         verbose_name_plural = _("Form fieldset entries")
         unique_together = (('form_entry', 'name'),)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
 
-class AbstractPluginEntry(models.Model):
-    """
-    Abstract plugin entry.
+@python_2_unicode_compatible
+class BaseAbstractPluginEntry(models.Model):
+    """Base for AbstractPluginEntry.
 
     :Properties:
 
-    - `form_entry` (fobi.models.FormEntry): Form to which the field plugin
-      belongs to.
-    - `plugin_uid` (str): Plugin UID.
-    - `plugin_data` (str): JSON formatted string with plugin data.
+        - `plugin_data` (str): JSON formatted string with plugin data.
     """
-    form_entry = models.ForeignKey(FormEntry, verbose_name=_("Form"))
-    plugin_data = models.TextField(verbose_name=_("Plugin data"), null=True,
-                                   blank=True)
 
-    class Meta:
+    plugin_data = models.TextField(
+        verbose_name=_("Plugin data"),
+        null=True,
+        blank=True
+    )
+
+    class Meta(object):
+        """Meta class."""
+
         abstract = True
 
-    #def __init__(self, *args, **kwargs):
-    #    """
-    #    Add choices.
-    #    """
-    #    super(AbstractPluginEntry, self).__init__(*args, **kwargs)
-    #    plugin_uid = self._meta.get_field('plugin_uid')
-    #    plugin_uid._choices = self.get_registered_plugins()
-
-    def __unicode__(self):
+    def __str__(self):
         return "{0} plugin for user {1}".format(
-            self.plugin_uid, self.form_entry.user
+            self.plugin_uid, self.entry_user
+        )
+
+    @property
+    def entry_user(self):
+        """Get user from the parent container."""
+
+        raise NotImplementedError(
+            "You should implement ``entry_user`` property!"
         )
 
     def get_registered_plugins(self):
-        """
-        """
-        raise NotImplemented("You should implement ``get_registered_plugins``"
-                             " method!")
+        """Get registered plugins."""
+        raise NotImplementedError(
+            "You should implement ``get_registered_plugins`` method!"
+        )
 
     def get_registry(self):
+        """Get registry."""
+        raise NotImplementedError(
+            "You should implement ``get_registry`` method!"
+        )
+
+    def plugin_uid_code(self):
+        """Plugin uid code.
+
+        Mainly used in admin.
         """
-        """
-        raise NotImplemented("You should implement ``get_registry`` method!")
+        return self.plugin_uid
+
+    plugin_uid_code.allow_tags = True
+    plugin_uid_code.short_description = _('UID')
+
+    def plugin_name(self):
+        """Plugin name."""
+        return dict(self.get_registered_plugins()).get(self.plugin_uid, '')
 
     def get_plugin(self, fetch_related_data=False, request=None):
-        """
+        """Get plugin.
+
         Gets the plugin class (by ``plugin_uid`` property), makes an instance
         of it, serves the data stored in ``plugin_data`` field (if available).
         Once all is done, plugin is ready to be rendered.
@@ -400,7 +643,7 @@ class AbstractPluginEntry(models.Model):
             return None
 
         # Creating plugin instance.
-        plugin = cls(user=self.form_entry.user)
+        plugin = cls(user=self.entry_user)
 
         # So that plugin has the request object
         plugin.request = request
@@ -409,21 +652,45 @@ class AbstractPluginEntry(models.Model):
             self.plugin_data, fetch_related_data=fetch_related_data
         )
 
-    def plugin_uid_code(self):
-        """
-        Mainly used in admin.
-        """
-        return self.plugin_uid
-    plugin_uid_code.allow_tags = True
-    plugin_uid_code.short_description = _('UID')
 
-    def plugin_name(self):
-        return dict(self.get_registered_plugins()).get(self.plugin_uid, '')
+class AbstractPluginEntry(BaseAbstractPluginEntry):
+    """Abstract plugin entry.
+
+    :Properties:
+
+    - `form_entry` (fobi.models.FormEntry): Form to which the field plugin
+      belongs to.
+    - `plugin_uid` (str): Plugin UID.
+    - `plugin_data` (str): JSON formatted string with plugin data.
+    """
+
+    form_entry = models.ForeignKey(
+        FormEntry,
+        verbose_name=_("Form"),
+        on_delete=models.CASCADE
+    )
+
+    class Meta(object):
+        """Meta class."""
+
+        abstract = True
+
+    # def __init__(self, *args, **kwargs):
+    #    """
+    #    Add choices.
+    #    """
+    #    super(AbstractPluginEntry, self).__init__(*args, **kwargs)
+    #    plugin_uid = self._meta.get_field('plugin_uid')
+    #    plugin_uid._choices = self.get_registered_plugins()
+
+    @property
+    def entry_user(self):
+        """Get user."""
+        return self.form_entry.user
 
 
 class FormElementEntry(AbstractPluginEntry):
-    """
-    Form field entry.
+    """Form field entry.
 
     :Properties:
 
@@ -434,53 +701,130 @@ class FormElementEntry(AbstractPluginEntry):
     - `form_fieldset_entry`: Fieldset.
     - `position` (int): Entry position.
     """
-    plugin_uid = models.CharField(_("Plugin name"), max_length=255,
-                                  choices=get_registered_form_element_plugins())
-    form_fieldset_entry = models.ForeignKey(FormFieldsetEntry,
-                                            verbose_name=_("Form fieldset"),
-                                            null=True, blank=True)
-    position = models.PositiveIntegerField(_("Position"), null=True, blank=True)
 
-    class Meta:
+    plugin_uid = models.CharField(
+        _("Plugin name"), max_length=255,
+        # choices=get_registered_form_element_plugins()
+    )
+    form_fieldset_entry = models.ForeignKey(
+        FormFieldsetEntry,
+        verbose_name=_("Form fieldset"),
+        null=True,
+        blank=True,
+        on_delete=models.CASCADE
+    )
+    position = models.PositiveIntegerField(
+        _("Position"),
+        null=True,
+        blank=True
+    )
+
+    class Meta(object):
+        """Meta class."""
+
         abstract = False
         verbose_name = _("Form element entry")
         verbose_name_plural = _("Form element entries")
-        ordering = ['position',]
+        ordering = ['position']
 
     def get_registered_plugins(self):
-        """
-        Gets registered plugins.
-        """
+        """Gets registered plugins."""
         return get_registered_form_element_plugins()
 
     def get_registry(self):
+        """Get registry."""
         return form_element_plugin_registry
 
 
 class FormHandlerEntry(AbstractPluginEntry):
-    """
-    Form handler entry.
+    """Form handler entry.
 
     :Properties:
 
-        - `form_entry` (fobi.models.FormEntry): Form to which the field plugin
-          belongs to.
+        - `form_entry` (fobi.models.FormEntry): Form to which the handler
+          plugin belongs to.
         - `plugin_uid` (str): Plugin UID.
         - `plugin_data` (str): JSON formatted string with plugin data.
     """
-    plugin_uid = models.CharField(_("Plugin name"), max_length=255,
-                                  choices=get_registered_form_handler_plugins())
 
-    class Meta:
+    plugin_uid = models.CharField(
+        _("Plugin name"),
+        max_length=255,
+        # choices=get_registered_form_handler_plugins()
+    )
+
+    class Meta(object):
+        """Meta class."""
+
         abstract = False
         verbose_name = _("Form handler entry")
         verbose_name_plural = _("Form handler entries")
 
     def get_registered_plugins(self):
-        """
-        Gets registered plugins.
-        """
+        """Gets registered plugins."""
         return get_registered_form_handler_plugins()
 
     def get_registry(self):
+        """Get registry."""
         return form_handler_plugin_registry
+
+
+class AbstractFormWizardPluginEntry(BaseAbstractPluginEntry):
+    """Abstract form wizard plugin entry.
+
+    :Properties:
+
+        - `form_entry` (fobi.models.FormWizardEntry): FormWizard to which the
+          plugin belongs to.
+        - `plugin_uid` (str): Plugin UID.
+        - `plugin_data` (str): JSON formatted string with plugin data.
+    """
+
+    form_wizard_entry = models.ForeignKey(
+        FormWizardEntry,
+        verbose_name=_("Form wizard"),
+        on_delete=models.CASCADE
+    )
+
+    class Meta(object):
+        """Meta class."""
+
+        abstract = True
+
+    @property
+    def entry_user(self):
+        """Get user."""
+        return self.form_wizard_entry.user
+
+
+class FormWizardHandlerEntry(AbstractFormWizardPluginEntry):
+    """Form wizard handler entry.
+
+    :Properties:
+
+        - `form_wizard_entry` (fobi.models.FormWizardEntry): FormWizard to
+          which the handler plugin belongs to.
+        - `plugin_uid` (str): Plugin UID.
+        - `plugin_data` (str): JSON formatted string with plugin data.
+    """
+
+    plugin_uid = models.CharField(
+        _("Plugin name"),
+        max_length=255,
+        # choices=get_registered_form_handler_plugins()
+    )
+
+    class Meta(object):
+        """Meta class."""
+
+        abstract = False
+        verbose_name = _("Form wizard handler entry")
+        verbose_name_plural = _("Form wizard handler entries")
+
+    def get_registered_plugins(self):
+        """Gets registered plugins."""
+        return get_registered_form_wizard_handler_plugins()
+
+    def get_registry(self):
+        """Get registry."""
+        return form_wizard_handler_plugin_registry
